@@ -1,5 +1,3 @@
-//! # bpf-rs
-//!
 //! `bpf-rs` is a safe, lean library for inspecting and querying eBPF objects. A lot of the
 //! design & inspiration stems from [bpftool](https://github.com/libbpf/bpftool) internals and
 //! [libbpf-rs](https://docs.rs/libbpf-rs).
@@ -7,13 +5,13 @@
 //! It is based upon the work of [libbpf-sys](https://github.com/libbpf/libbpf-sys) to safely create
 //! wrappers around [libbpf](https://github.com/libbpf/libbpf).
 //!
-//! # Non goals
-//!
-//! This crate is **NOT** meant to help with writing and loading of eBPF programs
+//! This crate is **NOT** meant to help with writing and loading of sophisticated eBPF programs
 //! and maps. For that, we recommend [libbpf-rs](https://docs.rs/libbpf-rs) and
 //! [libbpf-cargo](https://docs.rs/libbpf-cargo).
 //!
 
+pub mod insns;
+
 use libbpf_sys::{
     _bpf_helper_func_names, libbpf_probe_bpf_helper, libbpf_probe_bpf_map_type,
     libbpf_probe_bpf_prog_type, __BPF_FUNC_MAX_ID,
@@ -28,6 +26,8 @@ use std::{
 };
 use thiserror::Error as ThisError;
 
+pub use libbpf_sys;
+
 #[derive(ThisError, Debug)]
 pub enum Error {
     #[error("errno: {0}")]
@@ -412,64 +412,10 @@ impl Iterator for BpfHelperIter {
     }
 }
 
-pub mod insns {
-    use libbpf_sys::{
-        bpf_insn, BPF_JLT, BPF_JNE, BPF_REG_0, BPF_REG_1, BPF_SUB, _BPF_ALU64_IMM, _BPF_EXIT_INSN,
-        _BPF_JMP32_IMM, _BPF_JMP_IMM, _BPF_MOV64_IMM,
-    };
-    use num_enum::{IntoPrimitive, TryFromPrimitive};
-
-    #[repr(u8)]
-    #[derive(Debug, TryFromPrimitive, IntoPrimitive, Clone, Copy, PartialEq, Eq, Hash)]
-    pub enum BpfRegister {
-        R0 = BPF_REG_0 as u8,
-        R1 = BPF_REG_1 as u8,
-    }
-
-    #[repr(u8)]
-    #[derive(Debug, TryFromPrimitive, IntoPrimitive, Clone, Copy, PartialEq, Eq, Hash)]
-    pub enum BpfOp {
-        Sub = BPF_SUB as u8,
-    }
-
-    #[repr(u8)]
-    #[derive(Debug, TryFromPrimitive, IntoPrimitive, Clone, Copy, PartialEq, Eq, Hash)]
-    pub enum BpfJmp {
-        JNE = BPF_JNE as u8,
-        JLT = BPF_JLT as u8,
-    }
-
-    pub fn mov64_imm(reg: BpfRegister, imm: i32) -> bpf_insn {
-        unsafe { _BPF_MOV64_IMM(reg.into(), imm) }
-    }
-
-    pub fn alu64_imm(op: BpfOp, reg: BpfRegister, imm: i32) -> bpf_insn {
-        unsafe { _BPF_ALU64_IMM(op.into(), reg.into(), imm) }
-    }
-
-    pub fn jmp_imm(jmp: BpfJmp, reg: BpfRegister, imm: i32, off: i16) -> bpf_insn {
-        unsafe { _BPF_JMP_IMM(jmp.into(), reg.into(), imm, off) }
-    }
-
-    pub fn jmp32_imm(jmp: BpfJmp, reg: BpfRegister, imm: i32, off: i16) -> bpf_insn {
-        unsafe { _BPF_JMP32_IMM(jmp.into(), reg.into(), imm, off) }
-    }
-
-    pub fn exit() -> bpf_insn {
-        unsafe { _BPF_EXIT_INSN() }
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
 
-    #[test]
-    fn it_works() {
-        let result = 2 + 2;
-        assert_eq!(result, 4);
-    }
-
     #[test]
     fn bpf_helper_iter() {
         let count = BpfHelperIter::new()
